Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(110)

Unified Diff: net/base/net_log_event_type_list.h

Issue 9802003: SPDY - persist SPDY settings. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/base/net_log_event_type_list.h
===================================================================
--- net/base/net_log_event_type_list.h (revision 127896)
+++ net/base/net_log_event_type_list.h (working copy)
@@ -975,12 +975,14 @@
// }
EVENT_TYPE(SPDY_SESSION_SEND_SETTINGS)
// Receipt of a SPDY SETTINGS frame.
// The following parameters are attached:
// {
-// "settings": <The list of setting id:value pairs>,
+// "id": <The setting id>,
+// "flags": <The setting flags>,
+// "value": <The setting value>,
// }
-EVENT_TYPE(SPDY_SESSION_RECV_SETTINGS)
+EVENT_TYPE(SPDY_SESSION_RECV_SETTING)
// The receipt of a RST_STREAM
// The following parameters are attached:
@@ -975,12 +975,14 @@
// }
EVENT_TYPE(SPDY_SESSION_SEND_SETTINGS)
-// Receipt of a SPDY SETTINGS frame.
+// Receipt of a SPDY SETTING frame.
// The following parameters are attached:
// {

Powered by Google App Engine
This is Rietveld 408576698